Crate tryx_core

Crate tryx_core 

Enums

ControlFlow
Used to tell an operation whether it should exit early or go on as usual.

Traits

TryxResidual
Marker for residual types that belong to this workspace’s outcome family.
FromResidualExperimental
Used to specify which residuals can be converted into which crate::ops::Try types.
TryExperimental
The ? operator and try {} blocks.